[nautilus] Don't disable next pane ops if tabs are disabled
- From: Alexander Larsson <alexl src gnome org>
- To: svn-commits-list gnome org
- Cc:
- Subject: [nautilus] Don't disable next pane ops if tabs are disabled
- Date: Wed, 16 Dec 2009 12:14:48 +0000 (UTC)
commit 3bd562283262314fc8dd9840a3c1b5d390ab1860
Author: Alexander Larsson <alexl redhat com>
Date: Wed Dec 16 11:58:49 2009 +0100
Don't disable next pane ops if tabs are disabled
src/file-manager/fm-directory-view.c | 6 +++---
1 files changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/src/file-manager/fm-directory-view.c b/src/file-manager/fm-directory-view.c
index 122cce3..8722932 100644
--- a/src/file-manager/fm-directory-view.c
+++ b/src/file-manager/fm-directory-view.c
@@ -8849,8 +8849,10 @@ real_update_menus (FMDirectoryView *view)
action = gtk_action_group_get_action (view->details->dir_action_group,
FM_ACTION_OPEN_IN_NEW_TAB);
gtk_action_set_visible (action, FALSE);
+ }
- /* next pane actions */
+ /* next pane actions, only in navigation mode */
+ if (nautilus_window_info_get_window_type (view->details->window) != NAUTILUS_WINDOW_NAVIGATION) {
action = gtk_action_group_get_action (view->details->dir_action_group,
FM_ACTION_COPY_TO_NEXT_PANE);
gtk_action_set_visible (action, FALSE);
@@ -8859,11 +8861,9 @@ real_update_menus (FMDirectoryView *view)
gtk_action_set_visible (action, FALSE);
}
-
action = gtk_action_group_get_action (view->details->dir_action_group,
FM_ACTION_OPEN_FOLDER_WINDOW);
gtk_action_set_visible (action, show_open_folder_window);
-
/* Broken into its own function just for convenience */
reset_open_with_menu (view, selection);
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]